import requests
import time

class TTSClass:
    def __init__(self, msg="", lang='en'):
        self.msg = msg
        self.lang = lang
        self.convert_text_to_speech()

    def convert_text_to_speech(self):
        if self.msg == "":
            raise Exception('Parameter is Blank !!!')

        message_string = self.msg
        encoded_str = message_string.replace(" ", "+")
        lang = self.lang

        if len(encoded_str) > 100:
            raise Exception('Parameter is more than 100 character.')

        url = f'https://translate.google.com/translate_tts?ie=UTF-8&tl={lang}&client=tw-oa&q={encoded_str}'
        r = requests.get(url)
        current_date_and_time_string = str(time.strftime("%Y%m%d-%H%M%S"))
        extension = ".mp3"
        file_name = current_date_and_time_string + extension
        open(file_name, 'wb').write(r.content)
        return True



from setuptools import setup
from pathlib import Path

this_directory = Path(__file__).parent
long_description = (this_directory / "readme.md").read_text()

setup(
    name='TTSUG',
    version='0.1.0',
    description='A Python package for converting the text to speech',
    long_description=long_description,
    long_description_content_type = 'text/markdown',
    url='https://github.com/swadeshrd/tts',
    author='Swadesh Ranjan Dash',
    author_email='swadesh5dash@gmail.com',
    license='MIT',
    packages=['tts'],
    install_requires=['requests'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)